Index: wp-includes/plugin.php
===================================================================
--- wp-includes/plugin.php	(revision 6201)
+++ wp-includes/plugin.php	(working copy)
@@ -35,18 +35,18 @@
  * the <tt>$tag</a> parameter.
  * @uses merge_filters Merges the filter hooks using this function.
  * @param string $tag The name of the filter hook.
  * @param string $string The text on which the filters hooked to <tt>$tag</tt> are applied on.
  * @param mixed $var,... Additional variables passed to the functions hooked to <tt>$tag</tt>.
- * @return string The text in <tt>$string</tt> after all hooked functions are applied to it.
+ * @return mixed The text in <tt>$mixed</tt> after all hooked functions are applied to it.
  */
-function apply_filters($tag, $string) {
+function apply_filters($tag, $value) {
 	global $wp_filter, $merged_filters;
 
 	if ( !isset( $merged_filters[ $tag ] ) )
 		merge_filters($tag);
 
 	if ( !isset($wp_filter[$tag]) )
-		return $string;
+		return $value;
 
 	reset( $wp_filter[ $tag ] );
 
@@ -55,13 +55,13 @@
 	do{
 		foreach( (array) current($wp_filter[$tag]) as $the_ )
 			if ( !is_null($the_['function']) ){
-				$args[1] = $string;
-				$string = call_user_func_array($the_['function'], array_slice($args, 1, (int) $the_['accepted_args']));
+				$args[1] = $value;
+				$value = call_user_func_array($the_['function'], array_slice($args, 1, (int) $the_['accepted_args']));
 			}
 
 	} while ( next($wp_filter[$tag]) !== false );
 
-	return $string;
+	return $value;
 }
 
 /**
@@ -35,18 +35,18 @@
  * @uses merge_filters Merges the filter hooks using this function.
  * @param string $tag The name of the filter hook.
- * @param string $string The text on which the filters hooked to <tt>$tag</tt> are applied on.
+ * @param mixed $value The value on which the filters hooked to <tt>$tag</tt> are applied on.
  * @param mixed $var,... Additional variables passed to the functions hooked to <tt>$tag</tt>.
